# Integrating an external widget - tkcalendar

Simple app that shows howto integrate an external widget in pygubu-designer.

Before you open example main.ui file with pygubu-designer, you need to register
the required builder. Open pygubu-designer go to Edit > Preferences > Custom Widgets
and add the module tkcalendarwidgets.py to the custom widget builders panel.
To try another example just remove the registered builder from preferences panel and add the correct one.

The full process is explained [here](https://github.com/alejandroautalan/pygubu-designer/wiki/Design-Reuse)
